Django “excontrib” Comments — Django Comments 1.5 documentation

### Navigation

- index
- modules |
- next |
- Django Comments 1.5 documentation »

# Django “excontrib” Comments

Django used to include a comments framework; since Django 1.6 it’s been separated to a separate project. This is that project.

This framework can be used to attach comments to any model, so you can use it for comments on blog entries, photos, book chapters, or anything else.

## Contents

- Quick start guide
- The comment models
- Signals sent by the comments app
- Customizing the comments framework
- Comment form classes
- Generic comment moderation
- Example of using the comments app
- Settings that `django_comments` understands
- Porting to `django_comments` from `django.contrib.comments`

### Navigation

- index
- modules |
- next |
- Django Comments 1.5 documentation »